

{{../../README.md}}


```eval_rst
.. toctree::
   :maxdepth: 3
   :caption: Table of Contents

   install
   initialisation
   quickstart
   recipes/index
   utils/index
   files/index
   todolist
   changes_link
```

## API Reference

```eval_rst
.. toctree::
   :hidden:
   :maxdepth: 30
   :caption: API reference

   autosummary
```

```eval_rst
.. toctree::
   :hidden:

   genindex
```


```eval_rst
.. include:: /autosummary_include.rst
```

## Acknowledgements

* SOXSPIPE makes use of [`ccdproc`](https://ccdproc.readthedocs.io/en/latest/index.html), an Astropy package for image reduction ([Craig et al. 2021](https://zenodo.org/record/4606771)).

{{../../CHANGES.md}}
